"use strict";(self.webpackChunk_anaconda_share_notebook=self.webpackChunk_anaconda_share_notebook||[]).push([[568],{1568:(e,o,a)=>{a.r(o),a.d(o,{default:()=>i});var n=a(1464),t=a(6947),r=a(2110),s=a(9369);const c=new(a(2123).ShareNotebookPlugin),i={id:"@anaconda/share_notebook:plugin",description:"A JupyterLab extension.",autoStart:!0,requires:[s.tokens.CoreToken,r.ILauncher,t.INotebookTracker,n.ICommandPalette,n.IThemeManager,n.IToolbarWidgetRegistry],activate:(e,o,a,n,t,r,s)=>{console.log("@anaconda/share_notebook:plugin extension is activated");const{corePlugin:i}=o,k={themeManager:r,corePlugin:i,notebookTracker:n,palette:t,toolbarRegistry:s};c.activate(e,k)}}}}]);